import React, { ReactNode, CSSProperties, ForwardedRef } from 'react';

declare type ListProps<T> = {
    list: T[];
    renderItem: (item: T) => ReactNode;
    style?: CSSProperties;
    hasMore: boolean;
    onFetchMore: (page: number) => void;
    currentPage?: number;
    /**
     * If height is set, the list will be scrollable else it will use the window scroller
     */
    height?: number;
    className?: string;
};
declare type ListHandler = {
    resetPage: () => void;
    scrollToTop: () => void;
};

declare const ListInner: <T>({ list, renderItem, style, hasMore, onFetchMore, height, className, }: ListProps<T>, ref: ForwardedRef<ListHandler>) => JSX.Element;
declare const List: <T>(props: ListProps<T> & {
    ref?: React.ForwardedRef<{
        resetPage: () => void;
    }> | undefined;
}) => ReturnType<typeof ListInner>;

export { List, ListHandler };
